package cn.com.ctop.kuaishou.modules.live.mapper;

import cn.com.ctop.kuaishou.modules.live.entity.LiveDataAccounts;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 直播数据——操作记录表
 *
 * @author jeecg-boot
 * 2022-04-01
 * @version V1.0
 */
public interface LiveDataAccountsMapper extends BaseMapper<LiveDataAccounts> {

    void updateAdState(@Param("accountId") String accountId);

    void updateAgeState(@Param("accountId") String accountId);

    void updateGenderState(@Param("accountId") String accountId);

    void updateMaterialState(@Param("accountId") String accountId);

    void updatePriceState(@Param("accountId") String accountId);

    void updateProvinceState(@Param("accountId") String accountId);

    void updateTouchState(@Param("accountId") String accountId);

    List<JSONObject> getTypeList();
}
