package cn.com.ctop.kuaishou.modules.live.service.impl;

import cn.com.ctop.kuaishou.modules.live.entity.LiveDataAccounts;
import cn.com.ctop.kuaishou.modules.live.mapper.LiveDataAccountsMapper;
import cn.com.ctop.kuaishou.modules.live.service.ILiveDataAccountsService;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 直播数据——操作记录表
 *
 * @author jeecg-boot
 * 2022-04-01
 * @version V1.0
 */
@Service
public class LiveDataAccountsServiceImpl extends ServiceImpl<LiveDataAccountsMapper, LiveDataAccounts> implements ILiveDataAccountsService {

    @Override
    public void updateOtherReport(String accountId) {
        baseMapper.updateAdState(accountId);
        baseMapper.updateAgeState(accountId);
        baseMapper.updateGenderState(accountId);
        baseMapper.updateMaterialState(accountId);
        baseMapper.updatePriceState(accountId);
        baseMapper.updateProvinceState(accountId);
        baseMapper.updateTouchState(accountId);
    }

    @Override
    public List<JSONObject> typeList() {
        return baseMapper.getTypeList();
    }
}
